@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc
 version: 1.17.0.3
-id: pandoc-1.17.0.3-257df634e15a54e32a712d876ce77ba5
-key: pando_CqT84VqTutCBL5A3uDfVvt
+id: pandoc-1.17.0.3-eb510c613bb58261320cda2a21b65c87
+key: pando_2AaKh2NjLYHBGK7r2eukD3
 license: GPL
 copyright: (c) 2006-2016 John MacFarlane
 maintainer: John MacFarlane <jgm@berkeley.edu>
@@ -85,7 +85,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.17.0.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.17.0.3
 data-dir: /usr/share/pandoc
-hs-libraries: HSpandoc-1.17.0.3-CqT84VqTutCBL5A3uDfVvt
+hs-libraries: HSpandoc-1.17.0.3-2AaKh2NjLYHBGK7r2eukD3
 depends:
     HTTP-4000.3.3-e80abaf8bcce3e49baa17e1fe8d694c7
     JuicyPixels-3.2.7-7a5ea2c8822f98f6d9837c143b0f3055
@@ -110,8 +110,8 @@ depends:
     haddock-library-1.2.1-51a4bfa148b95520f3c56461f9e3c4f2
     highlighting-kate-0.6.2-78975d33e6a60b626b8bbe418bb316e1
     hslua-0.4.1-5acb63b51e4a9d39e9aa4a0ad9006234
-    http-client-0.4.27-1cd31210c8ec4a6e0b4cc467bd24f592
-    http-client-tls-0.2.2-05f6aae0a8612df864dc61b6b7405a00
+    http-client-0.4.27.1-bb782af803807428bd58a3e7494afa2a
+    http-client-tls-0.2.3-dfa8d8f591f2399ab0bdf7c21e1d9977
     http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
@@ -131,8 +131,8 @@ depends:
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
     xml-1.3.14-6291d85df68e094bfca87f33fea8b24c
-    yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
-    zip-archive-0.3.0.1-2bfc79c766a6020efc6123272df9282f
+    yaml-0.8.17-256008eb42bc8c59588e1e26ecb14272
+    zip-archive-0.3.0.2-15b8e9a70ed3ab3db3683741297aa226
     zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
 haddock-interfaces: /usr/share/doc/pandoc/html/pandoc.haddock
 haddock-html: /usr/share/doc/pandoc/html
